package io.fabric8.kubernetes.api.model.rbac;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class KubernetesPolicyRuleBuilder extends KubernetesPolicyRuleFluentImpl<KubernetesPolicyRuleBuilder> implements VisitableBuilder<KubernetesPolicyRule,KubernetesPolicyRuleBuilder>{

    KubernetesPolicyRuleFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public KubernetesPolicyRuleBuilder(){
            this(true);
    }
    public KubernetesPolicyRuleBuilder(Boolean validationEnabled){
            this(new KubernetesPolicyRule(), validationEnabled);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRuleFluent<?> fluent){
            this(fluent, true);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRuleFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new KubernetesPolicyRule(), validationEnabled);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRuleFluent<?> fluent,KubernetesPolicyRule instance){
            this(fluent, instance, true);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRuleFluent<?> fluent,KubernetesPolicyRule instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiGroups(instance.getApiGroups()); 
            fluent.withNonResourceURLs(instance.getNonResourceURLs()); 
            fluent.withResourceNames(instance.getResourceNames()); 
            fluent.withResources(instance.getResources()); 
            fluent.withVerbs(instance.getVerbs()); 
            this.validationEnabled = validationEnabled; 
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRule instance){
            this(instance,true);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRule instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiGroups(instance.getApiGroups()); 
            this.withNonResourceURLs(instance.getNonResourceURLs()); 
            this.withResourceNames(instance.getResourceNames()); 
            this.withResources(instance.getResources()); 
            this.withVerbs(instance.getVerbs()); 
            this.validationEnabled = validationEnabled; 
    }
    public KubernetesPolicyRuleBuilder(Validator validator){
            this(new KubernetesPolicyRule(), true);
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRuleFluent<?> fluent,KubernetesPolicyRule instance,Validator validator){
            this.fluent = fluent; 
            fluent.withApiGroups(instance.getApiGroups()); 
            fluent.withNonResourceURLs(instance.getNonResourceURLs()); 
            fluent.withResourceNames(instance.getResourceNames()); 
            fluent.withResources(instance.getResources()); 
            fluent.withVerbs(instance.getVerbs()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public KubernetesPolicyRuleBuilder(KubernetesPolicyRule instance,Validator validator){
            this.fluent = this; 
            this.withApiGroups(instance.getApiGroups()); 
            this.withNonResourceURLs(instance.getNonResourceURLs()); 
            this.withResourceNames(instance.getResourceNames()); 
            this.withResources(instance.getResources()); 
            this.withVerbs(instance.getVerbs()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public KubernetesPolicyRule build(){
            KubernetesPolicyRule buildable = new KubernetesPolicyRule(fluent.getApiGroups(),fluent.getNonResourceURLs(),fluent.getResourceNames(),fluent.getResources(),fluent.getVerbs());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KubernetesPolicyRuleBuilder that = (KubernetesPolicyRuleBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
